@@ -40,8 +40,8 @@
 #include "drw-timer.h"
 
 #ifndef HAVE_APP_INDICATOR
-#define BLINK_TIMEOUT        200
-#define BLINK_TIMEOUT_MIN    120
+#define BLINK_TIMEOUT        1000
+#define BLINK_TIMEOUT_MIN    500
 #define BLINK_TIMEOUT_FACTOR 100
 #endif /* HAVE_APP_INDICATOR */
 
@@ -147,9 +147,9 @@ extern gboolean debug;
 static void
 setup_debug_values (DrWright *dr)
 {
-	dr->type_time = 5;
-	dr->warn_time = 4;
-	dr->break_time = 10;
+	dr->type_time = 300;
+	dr->warn_time = 150;
+	dr->break_time = 60;
 }
 
 #ifdef HAVE_APP_INDICATOR
@@ -561,11 +561,11 @@ settings_change_cb (GSettings  *settings,
         dr->state = STATE_START;
 
         if (!key || key == I_("type-time")) {
-                dr->type_time = 60 * g_settings_get_int (settings, "type-time");
+                dr->type_time = g_settings_get_int (settings, "type-time");
                 dr->warn_time = MIN (dr->type_time / 10, WARN_TIME_MAX);
 	}
 	if (!key || key == I_("break-time")) {
-                dr->break_time = 60 * g_settings_get_int (settings, "break-time");
+                dr->break_time = g_settings_get_int (settings, "break-time");
 	}
 	if (!key || key == I_("enabled")) {
                 GtkAction *action;
@@ -591,18 +591,37 @@ popup_break_cb (GtkAction *action, DrWright *dr)
 	}
 }
 
+static void
+setup_display_cb (gpointer data)
+{
+        g_setenv ("DISPLAY", (char *) data, TRUE);
+}
+
 static void
 popup_preferences_cb (GtkAction *action, DrWright *dr)
 {
 	GdkScreen *screen;
 	GError    *error = NULL;
 	GtkWidget *menu;
-        char *argv[] = { BINDIR"/gnome-control-center", "typing-break", NULL };
+        char *argv[] = { BINDIR "/gnome-control-center", "typing-break", NULL };
+        char *display;
 
 	menu = gtk_ui_manager_get_widget (dr->ui_manager, "/Pop");
 	screen = gtk_widget_get_screen (menu);
 
-	if (!gdk_spawn_on_screen (screen, "/", argv, NULL, 0, NULL, NULL, NULL, &error)) {
+        if (screen != NULL) {
+                display = gdk_screen_make_display_name (screen);
+        } else {
+                display = NULL;
+        }
+
+        if (!g_spawn_async ("/",
+                            argv,
+                            NULL /* envv */,
+                            0,
+                            setup_display_cb, display,
+                            NULL,
+                            &error)) {
 		GtkWidget *error_dialog;
 
 		error_dialog = gtk_message_dialog_new (NULL, 0,
@@ -618,6 +637,8 @@ popup_preferences_cb (GtkAction *action, DrWright *dr)
 
 		g_error_free (error);
 	}
+
+	g_free (display);
 }
 
 static void
@@ -631,7 +652,7 @@ popup_about_cb (GtkAction *action, DrWright *dr)
 	};
 
 	for (i = 0; authors [i]; i++)
-		authors [i] = _(authors [i]);
+		authors [i] = (char *) _(authors [i]);
 
 	gtk_show_about_dialog (NULL,
 			       "authors", authors,
